@@ -1,35 +1,43 @@
 # Claudio Perez
-__version__ = "0.0.1"
+__version__ = "0.0.4"
 
 from pathlib import Path
 
-from . import csmip, nga, eqsig, basic_formats
+from . import (
+    csmip,
+    nga,
+    eqsig,
+    basic_formats,
+)
 
 
 FILE_TYPES = {}
+FILE_TYPES.update(nga.FILE_TYPES)
 FILE_TYPES.update(csmip.FILE_TYPES)
 FILE_TYPES.update(eqsig.FILE_TYPES)
 FILE_TYPES.update(basic_formats.FILE_TYPES)
 
 DEFAULT_TYPES = {
+    ".at2": "nga.at2",
+    ".AT2": "nga.at2",
     ".zip": "csmip.zip",
     ".v2": "csmip.v2",
-    ".json": "json.record",
+    ".json": "json",
 }
 
 
-def read(read_file, *args, **kwds):
+def read(read_file, input_format=None, **kwds):
     """
     Generic ground motion reader
     """
-    if "input_format" in kwds and kwds["input_format"]:
-        typ = kwds["input_format"]
+    if input_format:
+        typ = input_format
     else:
         try:
             typ = DEFAULT_TYPES[Path(read_file).suffix]
         except KeyError:
             raise ValueError("Unable to deduce input format")
-    return FILE_TYPES[typ]["read"](read_file, *args, **kwds)
+    return FILE_TYPES[typ]["read"](read_file, **kwds)
 
 
 def write(write_file, ground_motion, write_format=None, *args, **kwds):
@@ -41,4 +49,3 @@ def write(write_file, ground_motion, write_format=None, *args, **kwds):
         except KeyError:
             raise ValueError("Unable to deduce output format")
     FILE_TYPES[typ]["write"](write_file, ground_motion, *args, **kwds)
-
